@@ -74,6 +74,7 @@
 #' 
 #' Hartmann, R., & Klauer, K. C. (2021). Partial derivatives for the first-passage time distribution in Wiener diffusion models. \emph{Journal of Mathematical Psychology, 103}, 102550. \doi{10.1016/j.jmp.2021.102550} 
 #' @examples
+#' 
 #' sample_list1 <- sampWiener(N = 100000, a = 1, v = .3, w = .5)
 #' hist(sample_list1$q, 200)
 #' 
@@ -236,3 +237,19 @@ sampWiener <- function(N,
   return(output)
 
 }
+
+
+#' @rdname sampWiener
+#' @examples
+#' 
+#' sample_list1 <- rWDM(N = 100000, a = 1, v = .3, w = .5)
+#' hist(sample_list1$q, 200)
+#' 
+#' sample_list2 <- rWDM(N = 100000, a = 1, v = .3, w = .5, ARS_STORE = TRUE)
+#' hist(sample_list2$q, 200)
+#' sample_list2$ars_store
+#' 
+#' sample_list3 <- rWDM(N = 100000, a = 1, v = .3, w = .5, ars_list = sample_list2$ars_store)
+#' hist(sample_list3$q, 200)
+#' @export
+rWDM <- sampWiener
\ No newline at end of file
